gossamer/compression
Parent module for the compression family — CompressionStream
and DecompressionStream. Hosts the shared
CompressionFormat type.
Types
Compression algorithms supported by CompressionStream and
DecompressionStream.
pub type CompressionFormat {
Deflate
DeflateRaw
Gzip
Brotli
}
Constructors
-
DeflateZlib-wrapped DEFLATE — DEFLATE compressed data inside a zlib header and Adler-32 trailer.
-
DeflateRawRaw DEFLATE — DEFLATE compressed data with no wrapper.
-
GzipGzip — DEFLATE compressed data wrapped in a gzip header and CRC-32 trailer.
-
BrotliBrotli compression.