gossamer/crypto

Values

pub fn get_random_values(
  array: uint8_array.Uint8Array,
) -> uint8_array.Uint8Array

Mutates the provided typed array with cryptographically secure random values.

Returns the same typed array, now populated with random values.

pub fn random_uuid() -> String

Generates a random RFC 4122 version 4 UUID using a cryptographically secure random number generator.

Returns a randomly generated, 36-character long v4 UUID.

Search Document