gossamer/blob

Types

A file-like object of immutable, raw data. Can be read as text, bytes, or a stream.

See Blob on MDN.

pub type Blob

Values

pub fn array_buffer(
  of blob: Blob,
) -> promise.Promise(
  Result(array_buffer.ArrayBuffer, js_error.JsError),
)

Reads the blob’s contents as an ArrayBuffer. Returns an error if the blob cannot be read.

pub fn bytes(
  of blob: Blob,
) -> promise.Promise(
  Result(uint8_array.Uint8Array, js_error.JsError),
)

Reads the blob’s contents as a Uint8Array. Returns an error if the blob cannot be read.

pub fn from_bytes(bytes: uint8_array.Uint8Array) -> Blob
pub fn from_bytes_with_type(
  bytes: uint8_array.Uint8Array,
  content_type content_type: String,
) -> Blob
pub fn from_string(content: String) -> Blob
pub fn from_string_with_type(
  content: String,
  content_type content_type: String,
) -> Blob
pub fn new() -> Blob
pub fn size(of blob: Blob) -> Int
pub fn slice(blob: Blob, from start: Int, to end: Int) -> Blob
pub fn slice_with_type(
  blob: Blob,
  from start: Int,
  to end: Int,
  content_type content_type: String,
) -> Blob
pub fn text(
  of blob: Blob,
) -> promise.Promise(Result(String, js_error.JsError))

Reads the blob’s contents as a UTF-8 string. Returns an error if the blob cannot be read.

pub fn type_(of blob: Blob) -> String
Search Document