gossamer/custom_event

Types

pub type CustomEvent

Values

pub fn detail(
  of event: CustomEvent,
) -> Result(dynamic.Dynamic, Nil)

Returns the detail value associated with the event, or an error if none was provided.

pub fn new(type_: String) -> CustomEvent

Creates a new CustomEvent with the given type.

pub fn new_with_detail(
  type_: String,
  detail detail: a,
) -> CustomEvent

Creates a new CustomEvent with the given type and detail value.

pub fn to_event(event: CustomEvent) -> event.Event

Converts a CustomEvent to a base Event for use with functions in gossamer/event.

Search Document