Provides information about files and allows JavaScript in a web page to access their content.
pub type File
pub fn from_blob(blob: blob.Blob, name: String) -> File
Creates a new File from a Blob.
File
Blob
pub fn from_strings(parts: List(String), name: String) -> File
Creates a new File from a list of strings.
pub fn last_modified(file: File) -> Int
pub fn name(file: File) -> String
pub fn to_blob(file: File) -> blob.Blob
Converts a File to a Blob for use with generic blob functions.