gossamer/form_data
Types
Values
pub fn append(
to form_data: FormData,
name name: String,
value value: String,
) -> FormData
Appends a new value onto an existing key, or adds the key if it does not already exist. Mutates the form data in-place and returns it for chaining.
pub fn append_blob(
to form_data: FormData,
name name: String,
value value: blob.Blob,
) -> FormData
Appends a blob value. Mutates the form data in-place and returns it for chaining.
pub fn append_blob_with_filename(
to form_data: FormData,
name name: String,
value value: blob.Blob,
named filename: String,
) -> FormData
Appends a blob value with a filename. Mutates the form data in-place and returns it for chaining.
pub fn delete(
from form_data: FormData,
name name: String,
) -> FormData
Deletes a key and all its values. Mutates the form data in-place and returns it for chaining.
pub fn entries(
of form_data: FormData,
) -> iterator.Iterator(#(String, FormDataValue), Nil, Nil)
pub fn for_each(
in form_data: FormData,
run callback: fn(String, FormDataValue) -> a,
) -> Nil
pub fn keys(
of form_data: FormData,
) -> iterator.Iterator(String, Nil, Nil)
pub fn set(
in form_data: FormData,
name name: String,
value value: String,
) -> FormData
Sets a new value for an existing key, or adds the key if it does not already exist. Mutates the form data in-place and returns it for chaining.
pub fn set_blob(
in form_data: FormData,
name name: String,
value value: blob.Blob,
) -> FormData
Sets a blob value. Mutates the form data in-place and returns it for chaining.
pub fn set_blob_with_filename(
in form_data: FormData,
name name: String,
value value: blob.Blob,
named filename: String,
) -> FormData
Sets a blob value with a filename. Mutates the form data in-place and returns it for chaining.
pub fn values(
of form_data: FormData,
) -> iterator.Iterator(FormDataValue, Nil, Nil)