gossamer/form_data
Types
Values
pub fn append(
form_data: FormData,
name: String,
value: String,
) -> FormData
Appends a new value onto an existing key, or adds the key if it does not already exist. Mutates the form data in-place and returns it for chaining.
pub fn append_blob(
form_data: FormData,
name: String,
value: blob.Blob,
) -> FormData
Appends a blob value. Mutates the form data in-place and returns it for chaining.
pub fn append_blob_with_filename(
form_data: FormData,
name: String,
value: blob.Blob,
filename: String,
) -> FormData
Appends a blob value with a filename. Mutates the form data in-place and returns it for chaining.
pub fn delete(form_data: FormData, name: String) -> FormData
Deletes a key and all its values. Mutates the form data in-place and returns it for chaining.
pub fn set(
form_data: FormData,
name: String,
value: String,
) -> FormData
Sets a new value for an existing key, or adds the key if it does not already exist. Mutates the form data in-place and returns it for chaining.
pub fn set_blob(
form_data: FormData,
name: String,
value: blob.Blob,
) -> FormData
Sets a blob value. Mutates the form data in-place and returns it for chaining.