gossamer/symbol
Types
Values
pub fn description(of symbol: Symbol) -> Result(String, Nil)
Returns the description of a symbol, or an error if it has none.
pub fn for(key: String) -> Symbol
Returns a symbol from the global registry for the given key, creating one if it does not already exist.
pub fn key_for(symbol: Symbol) -> Result(String, Nil)
Returns the registry key for a global symbol. Returns an error if the symbol is not in the global registry.