gossamer/text_decoder/text_decoder_option
Types
pub type TextDecoderOption {
Fatal
IgnoreBom
}
Constructors
-
FatalWhen set, decoding invalid data returns an error instead of substituting malformed data with a replacement character.
-
IgnoreBomIndicates whether the byte order mark will be included in the output or skipped over. It defaults to false, which means that the byte order mark will be skipped over when decoding and will not be included in the decoded text.